.. currentmodule:: pyfits

*******
Headers
*******

.. inheritance-diagram:: Header CardList

`Header`
========

.. autoclass:: Header
   :members:
   :inherited-members:
   :undoc-members:
   :show-inheritance:

`CardList`
==========

.. autoclass:: CardList
   :members:
   :undoc-members:
   :show-inheritance:
